@@ -1,3 +1,2 @@
-$: << 'lib' << '.'
-
+$: << "./test/"
 Dir['{spec,test}/**/*.rb'].each { |f| require f }
